package com.sky.mapper;

import com.github.pagehelper.Page;
import com.sky.annotation.AutoFill;
import com.sky.dto.DishPageQueryDTO;
import com.sky.entity.Dish;
import com.sky.enumeration.OperationType;
import com.sky.vo.DishVO;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;
import java.util.Map;

@Mapper
public interface DishMapper {

    /**
     * 根据分类id查询菜品数量
     *
     * @param categoryId Long
     * @return Integer
     */
    Integer countByCategoryId(Long categoryId);

    /**
     * 新增菜品和口味
     *
     * @param dish Dish
     */
    @AutoFill(value = OperationType.INSERT)
    void insert(Dish dish);

    /**
     * 菜品分页查询
     *
     * @param dishPageQueryDTO DishPageQueryDTO
     * @return Page<DishVO>
     */
    Page<DishVO> pageQuery(DishPageQueryDTO dishPageQueryDTO);

    /**
     * 判断当前菜品是否能被删除---是否存在起售菜品
     *
     * @param id Long
     * @return Dish
     */
    Dish getById(Long id);

    /**
     * 删除菜品表中的菜品数据
     *
     * @param id Long
     */
    void deleteById(Long id);

    /**
     * 删除菜品表中的菜品数据
     *
     * @param ids List<Long>
     */
    void deleteByIds(List<Long> ids);

    /**
     * 删除原有口味数据
     *
     * @param dish Dish
     */
    @AutoFill(value = OperationType.UPDATE)
    void update(Dish dish);

    /**
     * 条件查询菜品和口味
     *
     * @param dish Dish
     * @return List<Dish>
     */
    List<Dish> list(Dish dish);

    /**
     * 起售套餐时，判断套餐内是否有停售菜品，有停售菜品提示"套餐内包含未启售菜品，无法启售"
     *
     * @param id Long
     * @return List<Dish>
     */
    List<Dish> getBySetmealId(Long id);

    /**
     * 根据条件统计菜品数量
     *
     * @param map
     * @return
     */
    Integer countByMap(Map map);
}
