package com.sky.mapper;

import com.github.pagehelper.Page;
import com.sky.annotation.AutoFill;
import com.sky.dto.SetmealPageQueryDTO;
import com.sky.entity.Setmeal;
import com.sky.entity.SetmealDish;
import com.sky.enumeration.OperationType;
import com.sky.vo.DishItemVO;
import com.sky.vo.SetmealVO;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface SetMealDishMapper {
    /**
     * 查询对应套餐id
     *
     * @param dishIds List<Long>
     * @return List<Long>
     */
    List<Long> getSetMealDishIds(List<Long> dishIds);

    /**
     * 根据套餐id查询菜品选项
     *
     * @param setmealId LongLong
     * @return List<DishItemVO>
     */
    List<DishItemVO> getDishItemBySetmealId(Long setmealId);

    /**
     * 菜品起售停售
     *
     * @param setmeal Setmeal
     */
    @AutoFill(OperationType.UPDATE)
    void update(Setmeal setmeal);

    /**
     * 保存套餐和菜品的关联关系
     *
     * @param setmealDishes List<SetmealDish>
     */
    void insertBatch(List<SetmealDish> setmealDishes);

    /**
     * 分页查询
     *
     * @param setmealPageQueryDTO SetmealPageQueryDTO
     * @return Page<SetmealVO>
     */
    Page<SetmealVO> pageQuery(SetmealPageQueryDTO setmealPageQueryDTO);

    /**
     * 根据套餐id删除套餐和菜品的关联关系
     *
     * @param setmealId Long
     */
    void deleteBySetmealId(Long setmealId);

    /**
     * 根据套餐id查询套餐和菜品的关联关系
     *
     * @param id Long
     * @return List<SetmealDish>
     */
    List<SetmealDish> getBySetmealId(Long id);
}
