package com.sky.mapper;

import com.sky.annotation.AutoFill;
import com.sky.entity.Setmeal;
import com.sky.enumeration.OperationType;
import com.sky.vo.DishItemVO;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;
import java.util.Map;

@Mapper
public interface SetmealMapper {
    /**
     * 根据分类id查询套餐的数量
     *
     * @param id Long
     * @return Integer
     */
    Integer countByCategoryId(Long id);

    /**
     * 动态条件查询套餐
     *
     * @param setmeal Setmeal
     * @return List<Setmeal>
     */
    List<Setmeal> list(Setmeal setmeal);

    /**
     * 根据套餐id查询菜品选项
     *
     * @param setmealId
     * @return
     */
    List<DishItemVO> getDishItemBySetmealId(Long setmealId);

    /**
     * 向套餐表插入数据
     *
     * @param setmeal Setmeal
     */
    @AutoFill(OperationType.INSERT)
    void insert(Setmeal setmeal);

    /**
     * 套餐起售停售
     *
     * @param setmeal Setmeal
     */
    @AutoFill(OperationType.UPDATE)
    void update(Setmeal setmeal);


    /**
     * 根据id获取套餐
     *
     * @param id Long
     * @return Setmeal
     */
    Setmeal getById(Long id);

    /**
     * 删除套餐表中的数据
     *
     * @param setmealId Long
     */
    void deleteById(Long setmealId);

    /**
     * 根据条件统计套餐数量
     *
     * @param map
     * @return
     */
    Integer countByMap(Map map);
}
